package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$"`0`````````````"`!(````!``$8P````#0``,?$```!```T`"``
M"``H`!L`&@````8````T``$`-``!`#0```$````!``````4````$`````P``
M`30``0$T``$!-````!,````3````!`````$````!```````!`````0````"Z
M6```NE@````%``$```````$``,````+````"P`````5(```5B`````<``0``
M`````@``P!0``L`4``+`%````1````$0````!@````0````$```!2``!`4@`
M`0%(````1````$0````$````!&1TY5```+9H``&V:``!MF@```#L````[```
M``0````$9'3E40``````````````````````````````!@````0O;&EB+VQD
M+6QI;G5X+G-O+C(```````0````0`````4=.50```````````@````8````2
M````!````!0````#1TY5`/PE6M>?'&8,,WK`#)IXO0!!]@AG````80````,`
M```@````"@@`$J"@$48""```@!@1`%8\``C"$14`#0(0`````"@``````"`B
M6```"@0*H`>$1&!%"$`!A`!)ESQ"/@@``0`D@%`A@0Q@"%I`27A``$`B0@`!
M``!``!D`A,",$)`0`@@``8*)D!`!0<)`0)A`+(`@`$``"00@`.0!E(#`=I>.
M`````P`````````$````!0````<````(````````````````````"0````L`
M```-````#@`````````/````$0```!4`````````%@``````````````%P``
M`!H````;````'P```"`````A````(P`````````D````)0```"@`````````
M*0```"H````K````+````"T`````````+@`````````R````,P`````````W
M```````````````X````.@```#L`````````/````#T````_````0@```$4`
M````````2````$D```!*````2P```````````````````$T`````````````
M````````````3P```%``````````4@````````!3````50````````!7````
M6```````````````60```%T`````````7P````````!A`````````&0```!F
M`````````&@```!I````:@```&P```!M````<!R3EE^0[UJC_X>.PAR3VU<+
MESH-.C/L1X0$4=(-@G2!:TKP>L6.07VO##_-(,XC]P*P="!\U&35*'=2X&;,
MKV;V/4XN7@#WV_^'I`?GG4BQ"@*GX/^N2LXM1][/`<9'XSW@#L;%A7-L`I`_
M['R6?C_>3F\UD`6)Q2))2682[YAAI/DC`1R3NYUG:)*@@9SYANS514,/.YI;
M?)U-080PA''6ZU4M:Z/=IZ]E`*.>XA0,&?8"HI[CS=J%I3(%8&RA^^W;8C(.
M[]/J'T`YR`[QC;G"P_OI_WTB2AR3WNW`XTNM'%AQV2+AT"MSL0XLO=:?&UG)
M%F`?0#M8+#_EPVC4(IA\DN.Z#N3_(?II>F["W9B*5S79BV($K9/!\.,WR._R
M0T\@A=X8?.B;%2+KWLEH6D]`G+G%#8*X,%]]&U%OBP&S<.-O=GU+T+W60PEJ
MJ,<BGY`'J5-1$`(=FYRI?H+ZT&*+]BSL?)I_:WR6\(;\+)_1^5$+[AW3V_.B
M,/_F#8)UD!!+9D-@=E]>S;)L!?%:ZA8-.:T]J`W\*4G[X*,8Q%?B4EJ25P_O
MTOU(_M\L']_%;ND0D'VVF\4N<;+5R)_*J]\`````````````````````````
M#```````````(````````!L``````````"````````1R``+$X``````2````
M```#.@`"PAP`````$@```````[X``L&``````!(```````/:``+#S``````2
M```````%C0`"Q3@`````(```%P``!<P``L5`````!!$``!<```)U``+!L```
M```2```````#MP`"Q'0`````$@```````F4``L,,`````!(```````6P``$P
MP````$02```,```#=P`"Q(``````$@```````Z(``L-L`````!(```````0/
M``+![``````2```````%#P`!2\````D`$@``#````*P``L%T`````!(`````
M``5)``$\`````8`2```,```$>0`"PF0`````$@```````X@``L.H`````!(`
M``````0G``+#D``````2```````!2P`"Q&@`````$@``````!3,``36@````
MU!(```P```5G``+#>``````2```````%VP`!0P````BP$@``#```!/(``1H`
M````4!(```P```.O``+!U``````2```````#_``"PL0`````$@```````CX`
M`L2P`````!(```````-R``+%!``````2```````!>P`"P@0`````$@``````
M!(P``L5(````!"$``!@```09``+#```````2```````#(@`"Q(P`````$@``
M`````RD``L%H`````!(```````/,``+#8``````2```````!B``"P>``````
M$@```````)L``L,8`````!(```````25``+%2``````0`/_Q```#'``"P[0`
M````$@```````T(``L*(`````!(```````$8``+$F``````2```````!^0`"
MQ%``````$@``````!(T``L5(````!"$``!@```#G``+$%``````2```````$
M_P`!5<`````($@``#````A<``L)``````!(```````6@``%5X````'02```,
M```"20`"P\``````$@``````!>@``3C@```!0!(```P```61``$8P````#@2
M```,```%"0`!5L``````$@``#0```Y$``L/P`````!(```````6:``$89```
M```2```+````T@`"Q$0`````$@```````^X``L&D`````!(```````/%``+$
M"``````2```````#40`!5M@````$$0``#@``!)P``L5(`````!``__$```1+
M``+#/``````2````````+P`"PO0`````$@``````!&,``L0X`````!(`````
M``5\``+%1`````01```7```!6``"PR0`````$@``````!9@``53`````.!(`
M``P```&<``+!F``````2```````$J``"U8@`````$`#_\0``!?H``4#@```"
M(!(```P```-@``+"$``````2````````^``"PC0`````$@```````',``L4<
M`````!(```````,(``+"?``````2```````"5P`"PYP`````$@```````08`
M`L4H`````!(```````$\``+#A``````2````````7@`"Q-0`````$@``````
M`>4``L*@`````!(````````]``+$(``````2```````$BP`"Q4@````$$0``
M&````],``L),`````!(```````'%``+"6``````2```````%)0`!+N````!@
M$@``#```!`<``L+H`````!(```````##``+#,``````2```````%BP`"Q3@`
M````$```%P``!%4``L2D`````!(```````%I``+!^``````2````````B@`"
MQ.P`````$@``````!54``3O`````*!(```P```*3``+"E``````2```````"
M@``"Q%P`````$@``````!(8``3Y````"D!(```P```&A``+"K``````2````
M```$-P`"PU0`````$@``````!"X``L0L`````!(```````*>``+%4````!,1
M```8```%T0`!7/@``%EN$0``#@```^<``L-(`````!(```````/A``+#_```
M```2```````!*@`"PMP`````$@```````W\``L3X`````!(```````1K``+"
MT``````2```````"C``"P]@`````$@```````=,``L3(`````!(```````8'
M``$Z(````:`2```,```$/@`"PG``````$@```````:8``L/D`````!(`````
M``.I``+!C``````2```````")P`"PB@`````$@``````!7```3V`````L!(`
M``P```!/``+$O``````2```````$X0`!-H`````0$@``#````;(``L&\````
M`!(```````(P``+"N``````2`````&QI8G!E<FPN<V\`7U]G;6]N7W-T87)T
M7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M`%!E<FQ?27-T
M871B=69?<'1R`%!E<FQ?<WES7VEN:70S`%!E<FQ?265X:71?9FQA9W-?<'1R
M`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%])8V]M<&-V7W!T<@!097)L
M7V%T9F]R:U]L;V-K`%!E<FQ?26-U<G-T86-K:6YF;U]P='(`<&5R;%]C;VYS
M=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%])<&%R<V5R7W!T<@!0
M97)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?271O<%]E;G9?
M<'1R`%!E<FQ?271A:6YT961?<'1R`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?;F5W
M4U9P=@!097)L7VYE=UA37V9L86=S`%!E<FQ?26EN7V5V86Q?<'1R`%!E<FQ?
M26]P7W!T<@!097)L7TEE=F%L7W)O;W1?<'1R`'!E<FQ?9G)E90!097)L7VUG
M7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7T=T
M:')?:V5Y7W!T<@!097)L7T=D;U]U;F1U;7!?<'1R`%!E<FQ?27!E<FQ?9&5S
M=')U8W1?;&5V96Q?<'1R`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L
M7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E
M=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA
M;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8G)E<V]L=BYS;RXR
M`&QI8FYS;"YS;RXQ`&QI8F1L+G-O+C(`;&EB;2YS;RXV`&QI8F-R>7!T+G-O
M+C$`;&EB=71I;"YS;RXQ`&QI8G!T:')E860N<V\N,`!P=&AR96%D7V=E='-P
M96-I9FEC`&-L;W-E`&]P96XV-`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`
M<F5A9`!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O
M<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?<W1A8VM?8VAK
M7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')T
M;VL`<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`;65M8W!Y`%]?<W1R;F-P
M>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!?7V-T>7!E7V)?
M;&]C`&=E='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`')E861D
M:7(V-`!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI
M8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`7V5D871A`%]?8G-S7W-T87)T`%]E
M;F0`+W5S<B]L:6(O<&5R;#4O-2XQ,"XP+W-P87)C+6QI;G5X+71H<F5A9"UM
M=6QT:2]#3U)%`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%]?;&EB
M8U]C<W5?9FEN:0!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A
M;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`9V5T7W5S97)N
M86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<VEZ95]L;V%D7VUE7S(`
M7U]D871A7W-T87)T`'AS7VEN:70`7U]L:6)C7V-S=5]I;FET`%A37TEN=&5R
M;F%L<U]005)?0TQ%05)35$%#2P!N86UE7VQO861?;65?,@!P87)?;6MT;7!D
M:7(`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`'!A<E]I;FET7V5N
M=@!'3$E"0U\R+C0`1TQ)0D-?,BXS`$=,24)#7S(N,RXR`$=,24)#7S(N,@!'
M3$E"0U\R+C,N-`!'3$E"0U\R+C````````````,`!P`#``,``0`!`````P``
M``$``P`#``4``0````$``P`#``,````!``,``0`!``,`!0````,````#``@`
M!P`"``,```````$``@`"```````#`````0````$````!``$``0`)``$````$
M``,``0`!``4````#``$````!`````0`!``8```````(`````````````````
M`P`#`````0`#`````0`)```````!```````!``,``P`#`````0`#``,````#
M``,``P````$`!`````,````!`````0`````````!``8```-'````$````'`-
M:6D4````"0``!A0````0#6EI$P````@```8>````$`EI&7(````&```&*```
M`!`-:6D2````!0``!C0````0"6D9=`````0```8^````$`UI:1`````#```&
M2@```````0`"```"^````!``````#6EI$@````<```8T````$`UI:1`````"
M```&2@```````L$H```!%````````L5(``!/$P```````L50``!@$P``````
M`L%H```C%0```````L%T```1%0```````L&````%%0```````L&,``!L%0``
M`````L&8``!"%0```````L&D```X%0```````L&P```)%0```````L&\``!Q
M%0```````L'(```!%0```````L'4```;%0```````L'@```E%0```````L'L
M```/%0```````L'X``!7%0```````L($```?%0```````L(0``!%%0``````
M`L(<```$%0```````L(H``!M%0```````L(T``!&%0```````L)````O%0``
M`````L),``!0%0```````L)8``!1%0```````L)D```3%0```````L)P``!J
M%0```````L)\``!(%0```````L*(```I%0```````L*4``!:%0```````L*@
M``!-%0```````L*L``!=%0```````L*X``!R%0```````L+$```<%0``````
M`L+0``!F%0```````L+<``!D%0```````L+H``!3%0```````L+T```]%0``
M`````L,````A%0```````L,,```+%0```````L,8```F%0```````L,D``!`
M%0```````L,P``!4%0```````L,\```\%0```````L-(``!B%0```````L-4
M``!>%0```````L-@```D%0```````L-L```.%0```````L-X```8%0``````
M`L.$``!+%0```````L.0```5%0```````L.<``!)%0```````L.H```4%0``
M`````L.T```H%0```````L/````Q%0```````L/,```&%0```````L/8``!G
M%0```````L/D``!K%0```````L/P```U%0```````L/\``!C%0```````L0(
M```Y%0```````L04```M%0```````L0@``!.%0```````L0L``!?%0``````
M`L0X```^%0```````L1$```W%0```````L10```K%0```````L1<``!;%0``
M`````L1H```6%0```````L1T```*%0```````L2````-%0```````L2,```B
M%0```````L28```J%0```````L2D``!6%0```````L2P```=%0```````L2\
M``!O%0```````L3(``!H%0```````L34``!,%0```````L3@```#%0``````
M`L3L``!8%0```````L3X``!E%0```````L4$```>%0```````L40```V%0``
M`````L4<``!'%0```````L4H``!*%0````"!P^`(K@/`%YWCOZ`O``!J?___
M_*X%X+@#````@A!@!,(%P`&`H&```H``!`$```!``&I/`0```$```$,!````
M0``/<0$```"!Q^`(@>@`````````````````````````````O!```)PCH!C2
M`Z!8E`.@7!$``$\7``!5&0``59`2(D"6$N'@F!,AP)H0``%``&I>`0``````
M`````````````)WCOZ`G``"QP@SA9("@8``20``:)0``L",``+"D%*`(HA1@
M#*(D0!(A``"QHSQ@`L($(6BB!'__@*!`$3I```Z"$"`!H!0A:((`8`'")```
M@RA@`L($@`&?P$```0```,($``"`H$`1"D__^8(`8`&"$"`!PBSA9('/X`@!
M````G>._H('/X`@!````,&@`!0$````!`````0````$```"=X[^@$0``L,("
M(!"`H&```D``"9`2(!`#````@A!@`("@8``"0``$`0```)_`0``!````@<_@
M"`$````!````G>._H('/X`@!````,&@`!0$````!`````0````$```"=X[^@
MR`X``(4I(!B`H*```D``#H80`!@)``!7@@8@`<@!(-3:20``R`A``(4XH!B`
MH(`-A2D@&(=D0`&`H*``$D__^H(`8`&!S^`(D!```S!H``0!`````0````$`
M``"=X[W(@A`@`(@&(!R&![[`Q`$``<0@P`&"`&`$@*!@0#)/__W$`0`!@@>^
M])H'O_3&`'_LQ`!``,@`?]2$&,`"Q@!_S(08@`2$&(`#AS"@'X0`@`*$$,`"
MQ"!@#((`8`2`H$`-,D__],8`?^S&!@``&Q:@G@4;MGK8!B`$FA-AF800HZ'4
M!B`(B2C@!0,CQN_6![[`D3#@&X(08-S2!B`,D!(`!(@*@`S@!B`0GBI`#.@'
MOM"@!``+B!/`!.0'OM27*R`>H`0`#?0'ON"9,R`"D`0`"/('ONB6$L`,V`>^
MQ(@"``20*H`#GBK`!.P'ONR2`D`,F`K``_@'OO"8$@`,T`>^R)("0`V2`D`,
MJ`4`#>X'OO24`H`(I`2`#>H'OOB1,2`;H@*`#9DI(`6X!P`-F!(`#-`'OLRN
M!<`-F`)`#+0&@`V5,.`"D`(`#9,HX!Z0`@`+DA)`"K(&0`V5*R`%E@D`":$S
M(!N6$\`+H!0`"IXJ0`R5*2`>H`1`$.('OMB),2`"E@0`"Y02@`2H!0`)B`L`
M"J8J@`N($\`$I`2`"MX'OMR4`@`$H@1`#9,RX!N>`\`-B2K@!:P%@`V($D`$
MT@>^Y*H%0`V1*R`>B`*`!)DS(`*2`D`-E2D@!9`2``RA,2`;F`K`"*`4``J8
M%,`,E2K@'J8J``27,N`"H`4`$.@'OOR4$H`+F`0`#)8)``J@*H`,EA3`"YX#
MP`KF![\`E`2`"Z($0`CD![\$D3,@&Z@%``V7*R`%I`2`#982``NF!,`-D2D@
M'I8"@`N),2`"E2K@!9`2``2[,N`;B`L`"+H70`J(%``$E2L@'J`J``N9,R`"
MH@1`'902@`R(!$`$X@>_")@*P`JZ*H`$F!0`#.`'OPRB!$`-M`:`")("0`J@
M!``-V@>_&)0#P`R1,2`;W@>_$)DI(`6:`T`"VB>^+)@2``S:![\<G@/``I@"
M@`S0![\4E2K@'IH#0`+:)[XPES+@`I`"``*W,R`;E!*`"Y<K(`6:"0`*MA;`
M"YH70`V7*2`>M@:`&XDQ(`*:!L`-EA+`!+HJ@`R("P`+MBK`#;H70`2L!8`+
MB2M@!;H"0!W2![\@ES-@&[(&0`K4![\DB!+`!-8'ORB2`D`"B`=`!)0"@`*U
M,2`;E@+``M8GOC3Z![\LERL@'IDS(`*6$L`,N@=``M@'OS3Z)[XX^@>_,)@#
M``+8)[Y`F2D@!;H'0`*T%H`,^B>^/)DK8!ZZ"T`+FS-@`K0&0!J8$P`-MA;`
M';8&@!N:"0`,NBK`!)8'``NZ%T`-N"L`&YLNX`68!<`,KS;@&ZP%@!WZ![\X
MFA7`#>X'OSR:!8`-[`>_0+H'0`*U,V`;K@7``NXGOD3N![]$L@6``JTI(!Z)
M,2`"K@7``NXGODBL%8`$R`>_3.X'OTBJ!4`6B`$``L@GOE")*V`%K@7``NXG
MODRT%H`$K@[`%HDNX!ZX%P`7MS;@`I8"P!J($0`;E@+`'*XM@`VX"T`$KA7`
M'*PI``OX![]0B`4`!)@#`!>I,N`;N`<``J\JX`6H%0`7[@>_5)@#`!3H![]8
MM@7``NX'OURT!0`"J2M@'JX%P`+$![]@FS-@`NXGOE2$`(`!Q">^6*@5``W$
M![]DKS,@&YH*P!2L%8`-I@3`%(0`@`'$)[Y<FBT`#(4K(`6N%<`"A2K@'JH%
M0!>7,N`"J@5`%H00@`NH"P`"EBB`%9H30!2$!(`"Z`>_:*4U8!N(`0`-FRU@
M!:P%``&I*R`>FA2`#>0'OVR9,R`"B`$`#=H'OW"H%0`,K@2``9H#0`':)[Y@
MF`U`%-H'OW2E,2`;EA+`#)@M``2B!$`4F@-``=HGOF3:![]XF@-``=HGOFC:
M![]\F@-``=HGOFR;*2`%I!2`#9LM8!ZD!,`2JS5@`I8$@`N:$T`5I@D`#:0K
M0`N8$P`3F@0`#>8'OX"A,N`;A`"`#)DJX`6H!,`!F!0`#.`'OX2$`(`,V`>_
MB*<PH!NJ!``!X`>_C)@#``'8)[YPF2D@'J`$``'@)[YTB3$@`N`'OY"8$P`$
MR`>_E*`$``'@)[YXB`$``<@GOGR@"L`,B2B@!:04@!"F%,`$H"L``HDJX!ZB
M!$`3ES+@`I@#P`S>![^<B!$`"Z($0!+D![^@E@B`!)X#P`'>)[Z`H!0`"]8'
MOYB0`@`$F@-`$*0$@`'D)[Z$H31@&Z8"P`'D![^LERB@'H4PH`*D!(`!Y">^
MC)\L8`66$L`"Q`>^+(@:P`2>%``/Y`>_M(@9`!&:`T`/F`,`!,@'OZB>`(`+
MQ`>_I*$S8!N(`0`!R">^B(DK8`6$`(`!Q">^+(@4``0#,IBPA2Q@'I@#``3(
M![XPHS1@`H(08=:$$(`1I`2``988@`N@`0`"B2M@'I8:P`V;,V`"D`(`"]8'
MO["C,R`;B!$`#809``*6`L`!UB>^,)H8@`S$![^XD@)`!)<K(`6>`\`-V@>_
MO)840`N$`(`!Q">^D)`"``N:`T`!VB>^E(4K(![B![_`F3,@`H00@`RB!$`!
MES(@&X@8@`2;*B`%E`*``IH2P`V>`\`-FAD`",@'O\29,^`;H`0`#=H'O\B(
M`0`!R">^F(DJ(!Z:`T`!VB>^G)$R(`+6![_,FRO@!8@1``C0![XTA!D``IH3
M``V8&(`/Q`>_T*`$``V2`D`,V`>_U)8"P`&$`(`!UB>^H)H"``3$)[XTES0@
M&Y@#``&%*^`>V">^I)\SX`+0![_8F2P@!800@`_>![_DF!+`#-8'OCB(&(`$
MD@)`#)`"``'0)[ZHF`+``I89`!#(![_<E`*`"]8'O^">`\`!D3)@&X@!``'(
M)[XXB2P@'I8"P`'6)[ZLH30@`MXGOK"7*F`%B!$`$.`'O_"6$@`+T`>^/(09
M``*4`H`+H`0``>`GOKB?,J`;E@(`!.`'O_R0&(`)Q`>_Z)H#0`C0![_LA@#`
M$(0`@`'$)[X\A2I@'I`"``'0)[ZTD2J@!9,R8`*0$\`(F@-`"(00@`G0![Y`
MGS-@&X@8@`22`@`"D!D`"L@'O_28`P`(T`>_^(@!``'()[Y`B2J@'I`"``'0
M)[Z\E3*@`I$K8`6($0`*U`>^1)`3P`B$&0`"F`,`"(08@`V0`,`!A`+``H,K
M8!ZZ!T`$FS-@`I<S(!N"$$`-ARL@!8@80`2&$L`#EAD`#(0`@`.2`D`+ARL@
M'IH"@`&9,R`"ERB@!880P`R),*`;@AC``8@1``N8&$`"U@>^2)("0`2Z!T`,
MB2B@'K(&0`.%,*`"F2I@!8@1``*#,F`;AAD``X(00`R8&,`)N@=``9H#0`R#
M*F`>A`+`!),R8`*9+V`%@A!`"8<W8!N(&$`$AA#`#)89`!V:`T`#Q@>^3+(&
M0`N),V`;ERM@!9@`P`&'+V`>B!$`"[LW8`*R!D`$R`>^4(80P!V"&,`!E@$`
M`XDK8!Z4&$`-FS-@`H0`@`J#-F`;B!$`#94N8`6&&0`#@A!`"IH8P!G4![Y4
MA`"``9@#``V#+F`>N`<`!+,V8`*;**`%@A!`&8<PH!N(&$`$AA#`#9H9``*8
M`P`#E@+`#8<HH!ZV!L`!A3"@`ILK(`6&$,`"B3,@&X(8P`&($0`-M`:``X4K
M(!Z6`L`$B!A`#)DS(`*X!P`$@S+@&X00@`R)*N`%AAB``X(00`2:&,`+N`<`
M`;8&P`V#*N`>B`*``I<RX`*;+R`%@A!`"]8'OEB'-R`;A!A``H80P`V8&(`<
MM@;``[0&@`R'+R`>F@+``;DW(`*9+N`%AA#`'(4VX!N"&,`!A!"`#((80!NT
M!H`"B`$``9DVX`*%+N`>@RZ@!800@`R7-J`;F!"``Y82P`&8"P`:B`$`"X((
M@`.7+J`>@A,``=@'OERU-J`"F@-``982P!J&`P`#@A+``JP%@`*5,2`;A`K`
M`IDI(`6""$`$F!*`#((00`+4![YDA2D@'IH#0`R),2`"A@#``800@`2N!<`+
MF3-@&X(0@`N)*V`%@@A`#8@3``26"(`+F2M@'H8`P`2;,V`"@A!`"Y@3``W:
M![Y@K`6``9<PX!N($P`"@@-``H@)``.;*.`%A`L``H@1``*:$L`-A2C@'IH%
M@`V',.`"K@7`!(00@`.(`H`,ERM@!880@`R5,V`;F`B`#(8(P`V6$H`+AA#`
M#-@'OFB6!<`+E2M@'H(`0`.;,V`"A@,``I,RX!N4$H`-F2K@!9H2@`*8$D`,
MA`J``IH+0`N"`$`,V`>^;),P8!N:$T`"A2K@'H@!``V7,N`"F@,`"H00@`N8
M$(`*E`B`"I<H8`68"P`!EA)`"Y@3``K4![YTDRA@'H@!``N#,&`"A@#`#)(2
M0`&H!0`"@A)``H0*0`*7,2`;@@A`!)DI(`6"$$`"F!+`#)H#0`&%*2`>A@#`
M#(DQ(`*J!4`)F3#@&X00@`2)*.`%@A"`"8@3``2""$`#F2C@'H@#0`3:![YP
MAS#@`I((@`F8$P`#@A!`"883``*H!0`!A@C`!((#0`*7,2`;A`L``ILI(`6&
M$,`"A2D@'IH2P`V),2`"F@4`#800@`2J!4`#B!"`#(8"@`R7*V`%F`B`#)4S
M8!N("0`-B!$`#)82@`O8![YXE2M@'I8%0`N;,V`"@@!`!)02@`V(`P`"DS+@
M&YH2@`*9*N`%A`J``I@20`R:"T`+@@!`#)H30`+8![Y\A2K@'H8`P`V7,N`"
MF@,`"I,P8!N$$(`+F!"`"I0(@`J7*&`%F`L``9820`N8$P`*U`>^@),H8!Z&
M`,`+@S!@`H@!``R2$D`!I@3``I<PX!N"$D`"F2C@!80*0`*""$`#F!+`#((0
M0`*(`0`,A2C@'IH#0`&',.`"@@*`"9<Q(!N$$(`#F2D@!880@`F8$L`,A@C`
M!)<I(!Z:`T`,V`>^A(DQ(`*2"(`)EA+`!(80P`F($L`"I@3``X@)``V&`P`"
ME3-@&X0*P`*9*V`%B!$``H4K8!Z8$H`,U`>^+)LS8`*8!,`,A!"`#8(`0`2:
M$(`+B`*`"Y,S(!N6"(`+E2L@!9H+0`R4$D`*FA-`"]8'OHB3*R`>@@!`"IDS
M(`*&`,`-DA)`#)H"P`*5,&`;F!)``I<H8`6$"D`"EA*`"Y@+``'4![Z,A@#`
M"Y@3``*%*&`>B`$`#(,P8`*8`H`)ERC@!800@`&5,.`;@A"`"982@`N2"(`)
MB`$`"X((0`/6![XPE2C@'H(00`F',.`"F@-``902@`."`L`"DS$@&X82@`*7
M*2`%A`J``I820`N&",`$F@-`"X80P`*7*V`%F`,``X4I(!ZD!(`*AS-@&XDQ
M(`*&$,`+A!"`!)@#``/&![Z0ES,@&Y08@`J4&H`-B`#``H<K8!Z"`$`*FS-@
M`I4K(`6&$,`-EA+`"M0'OI2$&,`"FRL@'H(`0`N6`H`#E!B`#)DS(`*D!(`*
MA3!@&YH30`R5*&`%AAM``X00@`J8&,`!I`2``H@!``R%*&`>H@1`#8,P8`*9
M+*`%A!"``8<TH!N:&(`-AA#`#-@'OIB:&T`2@@$``YH"P`V),&`;A@,``I<H
M8`69+*`>B!$`"Z4TH`*:`T`$E3-@&Y@3`!*(&P`"Q`>^G(@9``&6`(`,H@1`
M!(4H8!Z#,&`"B2M@!800@`&8&(`,B!*`!-0'OJ"8&P`-B`1`!(,K8!Z2`H`"
MFS-@`H8`P`R5,2`;@A!`#9DI(`6:&$`"Q`>^-)@2@`R:&T`$A@#`#)@`@`&%
M*2`>E@+`#8DQ(`*5,.`;A!"`!)LHX`6(&(`!FA*`#8@9``.:`L`-U@>^I)("
M0`2#*.`>AS#@`I0"P`*)*V`%@A!``Y<S8!N&&$`"Q`>^J(88P`V($L`$E@"`
M`8@"0`2%*V`>F`,``YLS8`*3,2`;A!"`#8<I(`6:&(`!P@>^.(820`.:&T`$
MA@,``Y@`0`*#*2`>E`*`#8DQ(`*3,.`;@A!`!)LHX`6(&$`"Q`>^K)H20`V(
M&0`#F@*`#90`@`&%*.`>E@+`!(<PX`*3,V`;A!"``XDK8`6&&(`!P@>^L(@2
M0`2&&,`-B`+`!)8`0`*#*V`>F`,``YLS8`*3,2`;@A!`#8<I(`6:&$`"Q`>^
M/(820`.:&T`$A@,``Y@`@`&%*2`>E`*`#8DQ(`*3,.`;A!"`!)LHX`6(&(`!
MP@>^M)H20`V(&0`#F@*`#90`0`*#*.`>E@+`!(<PX`*3,V`;@A!``\8'OKB)
M*V`%A!A``H@20`2$&(`-B`+`!)8`P`&'*V`>F`,``ILS8`*3,2`;AA#`#84I
M(`6:&,`!P@>^0(020`*:&T`$A`,``I@`0`.#*2`>E`*`#8DQ(`*3,*`;@A!`
M!,@'OKR;**`%AAA``YH20`V&&,`"F@*`#90!``&)**`>E@+``X4PH`*3,V`;
MB!$``H<K8`6$&0`!AA)``X08@`V&`L`#F`,``I<PX!N0`@`$@RM@'H4HX`6;
M,V`"A!+``H(00`V$`P`"ES"@&X@80`2;*.`>F!D``XDHH`68`H`,AS#@`H@2
MP`2:$T`#A@,`!)DPX!N6&T`!B2C@!98:P`*6`@`+B!,`!)DHH!Z(`L`$R"8`
M`,@&(`2%,*`"U@8@"(00@`R&`0`#V`8@#,@&(!"$`L`"F@,`#<8F(`2"`0`!
MQ"8@",(F(!#:)B`,@<_@"`$````P:``&`0````$````!`````0````$```"=
MX[^@@*8@`!)```0#``"Q@<_@")`0(`#F`&%(@*3@``)/__R"$``8Q$X``(88
MH#V`H``#AD`@`("@``*$0"``@(C``@)(``VD$"``@@!@`<1(0`"&&*`]@*``
M`X9`(`"`H``"A$`@`("(P`(R3__Y@@!@`:0@0!C@!,``@*0@``)'_^2B$``3
M$&@`!I`0`!#@!$``@*0@``)'_]Z0$``0DA``&$``97^4$``2@*(@`#)'__BB
M!&`$PDP`$H"@8#TR3__TH@1@!*(D0!.D!*`!HSQ@`N(F0`"!Q^`(D>P`$IWC
MOYB0$``8?___QI('O_R!Q^`(D>@`"`$````!````G>._H"$``+'P!"$\@*8_
M_Q)(``\1``!5?___\I`2(N"`HB```D``#+`0(`#"2@``@*!@`")(``;P)"$\
M@AA@,("@``&P0"``\"0A/('/X`@!````\"0A/('/X`@!````G>._F",``+&@
M![_\$&@`"J(484C$!$``@RA@`H(`@`&"`&`$Q`!``("@H``21__]Q"!__)`0
M`!A___^:DA``$("B(``23__TP@>__('/X`@!````,&@``P$````!````G>.P
M`"$___L1``!5H!0C^)P#OYB@!X`0D!(B\)00+_^2$``0P@'@%,(GO_R"$"``
M0`!E%P$```"BDB``!$``+(($?__$3``!@*"@``)(`!R`H&``(3__^Y(0("^@
M%"/XE!``$:`'@!!``&4;D!``$("B(``"0``>`0```$``92N0$"``0`!DEM`"
M``"2$``9E!``$$``9-26$``1Q`>__,(!X!2$F(`!@A`@`!)``!D!````@<_@
M"`$````"0``,DA`@+R$___NB$``!H!0C^*`'@!"4$``10`!D_Y`0`!"`HB``
M$D__Y@$```!``&4/D!`@`$``9'K0`@``DA``&4``9&Z4$``:$&__Y0$```!`
M`&30`0````$````!````G>._H)`0(`!``&4`,P``3-`"``"T$"``0`!D:;(6
M82!``&1VDA`__T``9/B0$"``0`!D8]`"```0@&4)D>@`"`$````P:``'`0``
M``$````!`````0````$````!````G>._H$``9.F0$"``0`!D5-`"``!``&00
M`0```,("``"0$"``0`!DX>``8`1``&1,T`(``$``9"D!````P@H``)`0(`!`
M`&39PBP@&$``9$30`@``0`!D``$```#"`@``D!`@`$``9-'@`&`$0`!D/-`"
M``!``&0<`0```,("``"0$"``P@!@$(,P8!=``&3'PC0@&D``9#+0`@``0`!C
M[@$```#"`@``D!`@`$``9+_@`&`$0`!D*M`"```3``!5E!`@`$``9*&2$F/@
MT"0@'$``9+:0$"``0`!D(=`"``!``&/=`0```,("``"0$"``0`!DKN``8`1`
M`&09T`(``$``8_`!````P@(``)`0(`!``&2FPB0@($``9!'0`@``0`!CS0$`
M``#"`@``D!`@`$``9)[@`&`$0`!D"=`"``!``&1M`0```,0"``"`H*```D``
M"H(0(`!``&24D!`@`$``8__0`@``0`!D8P$```#"`@``P@!@;,(D("1``&2+
MD!`@`$``8_;0`@``0`!CL@$```#"`@``D!`@`,(`8`1``&2"P"!@*$``8^W0
M`@``0`!CJ0$```#"`@``D!`@`,(`8`1``&1YP"!@+$``8^30`@``0`!CH`$`
M``#"`@``D!`@`$``9''@`&`$0`!CW-`"``!``&1A`0```,("``#")"`P@<_@
M"`$````P:``%`0````$````!`````0```)WCOSB`IB```D``7@$```#"3@``
M@*!@`!)```0!````@<_@"`$```!``&/@D!``&**2(``"1__[(0``524``%4K
M``!5H!0C`*04HPBJ%6,0J`>_F"\``#PM```00`!CZ)`0`!&`HB```D``+@$`
M``#""B`3Q`P``("@0`("2``ON@(@$\0,@`"`H$`"(D@`,L0/8`%``&/CD!``
M&*80``A``&/@D!``'9`$P`A``&/[D`(@`IH0`!V2$"`!E!`__Y80`!68$``8
M0`!D)Z80``B0$"`#DA``$T``8W64$``4@*(__P)```;"![^H@@A`%X"@0!8"
M0``E`0```$``8\R0$``30`!CFI`0`!-``&.\D!``$8"B(``R3__7P@H@$T``
M8]*0$``10`!CY9`0`!B!S^`(`0```,8/8`'$#"`!@*#``@)/_\8!````$&__
MS\0,@`#"#*`!@*"``1)/_\X!````Q`]@`L(,H`*`H(`!`D__NP$````0;__'
M`0```('/X`@!````?___GI`0`!,0;__=`0````$````!````G>._H$``8_F0
M$"``0`!C9-`"``!``&/+`0```)00``B2$``80`!C<)`0(`.`HB```D``!`$`
M``"!S^`(D!`@`$``8^HA```\0`!C5=`"``!``&.\`0```,0"(!`#```0A`B`
M$("@@`$B0``.D!``&$``8]Z0$"``0`!C2=`"``!``&.P`0```,("(!"@"$`0
M`P``*("D``$23__HD!``&$``8U22$"`"@*``"('/X`B08#__,&@``P$````!
M`````S__]X(08Y"=XX`!P@'@%,(GO_R"$"``(S__^T``8O$A```$HA1C^!<`
M`%6B!X`1&P``59@0``B6$N,8FA-C*)`0`!&2$"`!0`!CKY04(`&`HB``%D``
M"Y`0`!&P$"``Q`>__,(!X!2$F(`!@A`@`!)``!8!````@<_@"`$````C/__W
MHA1C\)00`!"B!X`10`!C?Y(0`!&@DB``!D__\;`0(`!``&-ED`0@`;"2(``"
M1__LDA``$4``8SR4$``0$&__Z,`N`!!``&-B`0````$````P:``#`0````$`
M``""$\``$+__QP$````!````,&@`!`$````!`````0```)WCOYC"3D``@AA@
M/8"@``&R9G__0`!C*Y`0`!FB$``(D@>__'___<>0$``8H)(@``)```\E``"Q
M0`!C(@$```"`I$`(&$``=H(0(`#$#D`!Q"P``84HH!B`H*``$D___((`8`&!
MS^`(D!`@`*`0(`#0!*%(DA`@",0"``"`H*```D``"8(0``B"`&`$Q`!``("@
MH``23__]H`0@`9($(`*3*F`"`P``L<0`87"`H*```D@`"H00(`%``&*?J2P@
M`M`DH4B`HB``$D``#J80``B!S^`(D!`__Y`0``E``&,7Q"!A<*:2(``"3__Z
MJ2P@`M($H4A``&,IE!``%.8DH4B"!"`!@RA@`L`DP`'@)[_\Q$X``((0`!B(
M&*`]@*``!(A`(`"`H``"A$`@`(")``("0``-AA`@`((`8`'$2$``AAB@/8"@
M``.&0"``@*```H1`(`"`B,`",D__^8(`8`&&($`8D`1@`N`$H4A``&+SD`(`
M`X"B(``"1__6T"0`%`,``+'&#@``Q`!A2,('O_R#*&`"P@"``84HX!B%.*`8
M@*"@``)``!+&*$``@*"@/0)``!"$$"`]$&@`!;`&(`&`H*`]`D``"X00(#W$
M#@``@@!@`8<HH!C$*$``A3C@&("@H``23__WL`8@`800(#W$*$``A!`@`,8.
M0`*(`$`"QBD@`8<HX!B`H.``$D__^X0`H`$0;_^4`0```.@'O_PE``"Q$&__
MNZDM(`(P:``%`0````$````!`````0```)WCOX`#``!7)0``5>``8-@#``!5
M(P``58(08TC")[_P*0``50,``%6D%*,PY">_Z((08U#")[_THA1C0`,``%7B
M)[_LJ!4C<((08UC")[_XI@>_\`,``%6"$&/@$&@`#<(GO_Q``&*B`0```("B
M(``"0``;`0```,),0`"`H&```D``%:00`!'B!,``I@3@!'___520$``2K!``
M"("B(``"0``&DA``&,)*``"`H&``$D__[0$```"0$``2?___09(0`!C"3$``
M@*!@`!)/_^^D$``1@<_@"`$```!``&)ID!``&*X0``A``&)FD!``$*H0``B0
M$``60`!B8JH%P!6J!6`"0`!B?9`%0`CL(Z!<E!`__Y80`!28$``8FA``$)(0
M(`%``&*HJA``")`0`!)___\DDA``%1!O_]'"3$``G>._>`4``%<A``!5@A"@
ML.P8H+"0%"-XQ!!@("4``%4C``!5U!A@$"<``%78&&`8Z!A@",(!X!3")[_\
M@A`@`-0_O^C8/[_PQ#>_^.P_O]A___TTZ#^_X!$``%5___TQD!(CB'___2^0
M%*.8?__]+9`48N!___TKD!3CJ!$``%5___THD!(CN!$``%5___TED!(CR!$`
M`%5___TBD!(CV!$``%5___T?D!(CZ!$``%5___S\D!(C^)*2(``B0``%$0``
M5G___N^0%..H$0``5G___/20$B`0@*(@``)```62$``($0``5G___N:0$B`H
M$0``5G___.N0$B`XDI(@``)``!`1``!6?__^WI`4HY@3``!6D!0C>'___MJ2
M$F!PQ`>__,(!X!2$F(`!@A`@`!)``!D!````@<_@"`$```!___S8D!(@2)*2
M(``B0``&$P``5G___LN0%&+@$&__[A,``%:0![_IDA)@8$``8CV4$"`*@*(@
M`#)/_^<3``!6D!1BX'___K^2![_S$&__XA,``%9``&(/`0````$```"=X[^@
M0`!A\[`0(`!``&'K`0```("B(``R2``"\`(``('/X`@!````,&@`!@$````!
M`````0````$````!````G>._H("F(``"0``I`0```,).``"`H&```D@`)0$`
M``!``&'0D!``&)`"/_^4!@`(@*8`"AI``!,)``!7P@$@U,9.``C$"$``A2B@
M&(,XH!B`H,`!(D@`")0"O_\0:``@A3B@&("@0`,R0``=A3B@&)0"O_^`I@`*
M*D__^\)*@`"`HH`8$D``'L8!(-3P`2#4Q$J``,).``"`H(`!`D``+@$````0
M@&(5@>@``$``8<N0$"`"@*(@``)```2"$"`NP"H@`<(J``"!Q^`(D>@`"("@
M0`("1__L@**`&)0"O_^`I@`**D__^\)*@`"`HH`8(D__Z/`!(-3&`2#4E`*_
M_X"F``HZ0``(E"*`&,1*@`#"2,``@*"``2)/__J4`K__E"*`&!<```2"`J`"
M@*!`"QA/_^:0$"``(0``L9(0`!B4`J`!0`!A&)`4(7@0;__?D!0A>$``8:&0
M$"`"@A``"("@8``"1__9D!`@`(00("[`*&`!D!```1!O_]3$*$``G>._H'__
M_Y^0$``8Q`H``(,HH!B`H&```D``#J`0``@%``!7D`(@`<0`H-3&2(``Q`H`
M`(,X8!B`H$`#@RB@&*%D0`B`H&``$D__^I`"(`%___Q$`0```("B(``"0``0
M`0```("F(``"0``-`0```,).``"`H&```D``"0$````3``!6D!``$$``87&2
M$F!X@*0`"`)```0!````@<_@"`$````0;_U'@>@```$````P:``$`0````$`
M```!````G>._F)`'H$22!Z!(\">@1)0'H$SR)Z!(0`!AF?0GH$P3``"P$0``
ML)(28;R0$B,80``%Q)00``E``&$*D!`@`,)*``"`H&``$D@`$0$```!``&$!
M`0````4``+6`HB```D``B=`@H7A``&$B`0```$``88:0$"``0`!@\=`"``!`
M`&%D`0```,`J``!``&%_D!`@`$``8.K0`@``0`!A?@$```""$``(D!`@`,0(
M0`"$$*`"0`!A=<0H0`!``&#@T`(``$``870!````P@H``(00(`""$&`!PBH`
M`-`'H$0#``!7D`(@!880``C$/[_X!0``5]$?O_B5H!$(T1A@X)6BB$C1&*#H
M@:J*R"U``%P1``"Q0`!A0I$J(`+6!Z!(!0``M8@0(`30(*&$@A``",8"P`#$
M!Z!$QB(```<``+7((.&`!P``5H"@H`&&$."`QB(@!`<``%>&$.#XQB(@"`<`
M`%:&$."(!$``"\8B(`R&$"`$B!`@`=@"P`.:`$`#B`$@`88`X`2`H(`$%$__
M^]@C8`R$`*`#(0``M=`$(7B4$``"$P``584HH`*2$F$`EA```9@0(`!``&!N
MP"!``K"2(``"0``0`0```$``8.W0!"%X$0``57__^ZJ0$B.(@*(@``)``!,C
M``"U0`!@6]`$(7A``&"P`0```('/X`@!````0`!@>=`$(7BP$``(0`!@W-`$
M(7@1``!5?__[F9`2(XB`HB``$D__\2,``+70!&%\@*(@`")```H1``!5?___
M0`$```!``&!$T`0A>$``8)D!````@<_@"`$```!___N(D!(CF("B(``"3__@
MT"1A?!!O__,!````0`!@XI`2(5!``&$0D!`@`0$````P:``$`0````$````!
M````G>.P`!$``%6<`[^0P@'@%,(GO_R"$"``?__[<I`2(Y@#``!7HA``".``
M8-20$``80`!@KY(0`!"`HB```D``#@$````1``!5DA``&'___5V0$B/(Q`>_
M_,(!X!2$F(`!@A`@`!)``&P!````@<_@"`$```!``&"#D!``&`,``%>J$``(
MY@!@V)`0`!E``&"GDA``$[B2(``"1__K)3__^RD``%6D%*/X+0``5:@5(P"J
M!6`!I`>`$JP5HW`[```\+P``(,)/``"`H&``N61`%("D8``"0``'D!``$4``
M8,F2$``<@*(@``)``#<!````0`!@9)`0`!R"!P`(Q$P``,9(?_^`H,`",D``
M#)`%0`C`*'__D`(__\8(?_[$3```ARC@&(<XX!B`H,`"`D__^8(`?_^0!4`(
M@*(O_Q1'_\*8$``<DA`@`?`CH%P5```$EA``%IH0`!!``&";D!``$D``8**0
M$"``0`!@#=`"``!``&!T`0```)00``B2$``20`!?XY`0(`.`HB``,D@`#I`0
M(`!``&"5`0```$``8`#0`@``0`!@9P$```#"`B`0@@A`'8"@0!<"0``*D!``
M$I`0(`!``&!9DA``$[B2(``R3_^^PD\``!!O_YP1``!50`!@!)(0(`&`HB``
M,D__]I`0(``1``!5DA``$G___/&0$B/(0`!@A9`0`!(0;_^2L!``"$``8#\!
M`````0````,__]^"$&*PG>.``0D__]\7``!6FA$C/)82X)C"`>`4PB>__((0
M(`"$!X`-(0``5=8@H`07``!5AA$C3*`4(^"($2,DX""@#)82XP#6(*`(!0``
M5H('@`2$$*"@Q"!@!`4``%:8!X`#A!"@J,0@8`@C``!5!0``5N`@8!20%&.8
MA!"@L,0@8`PG``!6!0``5B4``%;@(R`(A!"@N,0@8!`#``!6@A!@R"D``%;"
M(R`$IA3@D*04H"CF)X`-J!4@P.0G@`1___J_Z">``ZJ2(``"0``&`0```,)-
M0`"`H&``$D`!F0$```!___WV`0```*R2(``B0`&:*S__W^@-@`"I+2`8@*4@
M`")``!,I/__?0`!?O`$```""$``6AA`@7\0"``"I/2`7Q!"`%("(J``B2``"
MQBA``((`8`'H"$``J2T@&("E(``R3__WQ`(``"D__]^0$``2J!4C)*@'@!00
M:``&J`4@!,)*``"`H&```D`!7:@%(`1___J2`0```*22(``B1__YT`4``'__
M_!4!````@*(@`")/__30!0``0`!@%I`0`!*JDB``(D__[]`%``!``%^KD!``
M%:00``A``%^HD!``%I`$@`A``%_#D`(D!.PCH&`#``!7%P``5N@`8-0#``!6
MF!``%8(08'B6$N#8PB.@7)00/_^:$``4DA`@`:00``A``%_GKA``")(0(>U`
M`%\>D!``$A$``%5___IHD!(C4("B(``B0``*Y@8``$``7_'F!@``DA``"'__
M_NB0$``3II(@`")```+F!@``?__Z8P$```"`HB``(D@`/Y`0`!.0$``20`!?
M?2L``%:L$``($P``5A$``%62$F!PD!(BX'___$:F$"``0`!>_*H581#@(Z!@
M%P``5M`CH%R2$"`!EA+A`)`0`!*4$#__F!``$D``7[N:$``4$&@`%I`0`!)`
M`%[H`0```,("``"`H&`1$D``%9`48YC`+(`60`!>YZ8$X`'F(Z!@T".@7)(0
M(`&0$``2E!`__Y80`!7@(Z!DF!``$D``7Z::$``4D!``$D``7MV2$"'M@*(_
M_P)/_^F0%&.8?__\'9(0`!)___RKD!``$L0'O_S"`>`4A)B``8(0(``20`%6
ML!``%X'/X`@!````0`!?C)(0(`"PDB``(D__P9`0`!(3/___%3___RL__]^4
M$J/NEA`@`JH58UB2$F/_0`!>Y*8'@!60$``8E!`@!D``7ON2$``3P@^`%8"@
M8``22``'`QG12,(,X`&`H&!#(D``_L(,X`(#&=%(.S__W\`GOVR"$&,!PB>_
M6+H78U@#._-JP">_<+H'@!V"$&.)PB>_7*P'OU@#)BZWP">_M*H'OW2"$&#^
MPB>_8`,$#)6"$&!VPB>_9`,P]+B"$&'PPB>_:)`0`!B2$``=0`!>V!4``""F
MDB``!$``0\('OVR%+.`#A`"``8"@0`(82`"]Q@>_<(DTX!W"![^TMA``'88`
MP`3$)[]L@*!@``)(`!/&)[]PMA`@0)`%0`&V)L`!DA``'8"DP!NW9(`30`!>
M\)00`!O"![^T@@;``8"@8$`23__APB>_M)`0`!:F),`;?__TK;8'0!N`I.`_
M!$``%I00`!.X$"``D@;`')00($"0$``50`!>WK@'($!___2BD!``%H(DP!R`
MH&`_%$__^)(&P!RF!/_`@S3@!H4H8`:"`&`!@RA@!J8DP`*V!L`!E!``$Y(0
M`!N6$"!$0`!>EI`0`!7F)[^TD!``&)(0`!U``%Z7%0``(*:2(``43__!P@>_
M;$``7MV0$``8^`>_;/H'OW"&$#^`@S<@`X((8#^$!X`!@@!@`8"@8#@40`"Y
MQBB_=)00(#B0!4`!E"*``4``7G22$"``@S=@&,(OOZR0$``6@S=@$,(OOZVF
M![^X@S=@",(OOZXQ``!6@S<@&,(OO["L$``3@S<@$/HOOZ^J$"``^"^_L[DW
M(`BZ![_HPB^_L;`6(/A___1C^"^_LMH'OUC(![]<Q@>_8)<S8!C$![]DDS-@
M$)@0``O"![]HE3-@")$Q(!C6+[_HTB^_Z9<PX!B3,2`0U"^_ZMHOO^N5,2`(
MFS#@$-`OO^S2+[_MD3#@"-0OO^Z3,*`8R"^_[Y4PH!#6+[_PB3!@$)<PH`C:
M+[_QQB^_\YLP8!B',&`(T"^_\M(OO_34+[_UUB^_]L0OO_?:+[_XR"^_^<8O
MO_H0:``#PB^_^]@/0!60$``6F`L@_Y(0(`&4$#__EA``&$``7L*J!6`!@*5@
M%!)/__>L!:`"%P``5IH0`!3F(Z!<EA+@Z)`0`!+@(Z!@DA`@`900/__`+[_@
M0`!>M)@0`!(0;_\4D!1CF"4__]^D%*,\I`>`$A!H``:D!*`$PDS``("@8``"
M1_ZMI`2@!)`0`!-___JUJA`@`("B(``B3__XY@2``$``7K:0$``3JI(@`")/
M__/F!(``$&_^H`$````0;_]%A@#@`7__^Z<!````0`!>JY`0`!40;_[ZKA``
M")`0`!2J%6-,J@>`%:H%8`1___D5`0```("B(``B0``(T`5``$``7IX!````
MK)(@`#)'_EWH#8``T`5``,)*``"`H&``$D__\ZH%8`0M``!6$&_^::P5H2B`
MH&!!$D__!`,9T4C"#.`#@*!@0Q)/_P`#&=%(P@S@!("@8$@23_[\`QG12,(,
MX`6`H&!%$D_^^`,9T4@3/___%3___Y80(`*0$``8E!*CQD``7<:2$F/_DA``
M$Y`0`!A``%W=E!`@*>8CH%P7``!6FA``%.`CH&"6$N#HD!``$I(0(`&4$#__
M0`!>6I@0`!(0;_ZZD!1CF)00($"2$"``E"*``4``7;V0!4`!?__SP)`0`!;`
M)6`TP">_=,`E8`3`)6`(P"5@#,`E8!#`)6`4P"5@&,`E8!S`)6`@P"5@),`E
M8"C`)6`L$&__.L`E8#!``%X3`0````$````P:``$`0````$````!````G>._
MH$``7D&0$"``0`!=K-`"``!``%W"`0```((0(`'"*@``$0``57__^+:0$B-X
M@*(@``)```8!````PDH``("@8#$B0`#VPDH@`7__^X4!````0`!>+9`0(`!`
M`%V8T`(``!,``%:4$"`!DA)A,$``7826$"`+@*(@``)``$,!````[`(@"((-
MH/^"`'_W@*!@`1A``=0O```P`P``(*P-@!>`I8`!$D`"#SL``+7$`B`,HA`@
M!,('88"@$"``@*!@`01``"WF`*`8*0``M:H788"H%2&$0`!>#)`0(`!``%UW
MT`(``)(0`!.4$``00`!=NY80(`"XDB```D``L\('88#&!P``Q`4``,(`X`B`
MB&0``D``GN0`@!&$"&#_@*"@!`A``7J`H*`+`D`!<H"@H`P"0`%J@@A`%X"@
M0!8"0`"*A`"_]](`X`Q``%WUD!``$H"B(``20`"<P@=A@*`$(`'"!4``A`0@
M`8"@0`(43__:H@1@!(0`?_^`H(`0`D``EH"@8`%``%W@D!`@`$``74O0`@``
M$P``5I00(`&2$F/`0`!=-Y80(`6@DB```D``)@$```!``%W4D!`@`$``73_0
M`@``Y`0@"((,H/^"`'_W@*!@`1A``;@C```P`P``(*0,@!&`I(`!,D`!BA$`
M`%;"!"`,%0``5I02H\A``%TFT@!``.8$(`B"#.#_@@!_]X"@8`$80`%YI@S`
M$8"DP!(20`&K$0``5L($(`S"`$``Q`!@"`,`$`"`B(`!$D``?`$```!``%VP
MD!`@`$``71O0`@``$P``5I00(`&2$F/00`!=!Y80(`6@DB``(D``&Y`0(``1
M``!5?__X(9`2(\BBDB```D``Q0$```!``%V>D!`@`$``70G0`@``P@0@"(0(
M8/^$`+_W@*"@`1A``7P%```P@@A``@4``""`H$`"$D`!9900`!'"!"`,0`!<
M\M(`0`"0$"``0`!=BR4``+5``%SVT`(``$``70P!````P"H``$``7820$"``
M0`!<[]`"``!``%V)`0```,`B```1``!5?__W^I`2(YB`HB```D``5=`DH7Q`
M`%RHDA`A[8(:(!&`H``!A$`@`("@``B"0"``@(B``0)```66$``(@*(__Q)`
M`30#``"U@<_@"`$```"`H*`!.$__>-(`X`P1``!6$P``5I`2(3B2$F,80`!=
M0)00(")``%U?D!`@`$``7,K0`@``T@<``)00(`!``%UQEA`@`I(0``A``%U<
MD!``$H"B(``B3_]JH`0@`<('88"$`'__@*"`$!)/_VZ`H&`!!$?_;*`0(`$C
M``"UHA1A@)`0(`!``%U'H`0@`4``7++0`@``0`!<GI(0`!/"!$``@*!`$#1/
M__B0$"``$&__70$```"`H&```D__#0$````0;_\)`0```$``73:0$"``0`!<
MH=`"``#"!"`(A`A@_X0`O_>`H*`!&$``ZX((0!&`H$`3,D`!'1$``%;"!"`,
M0`!<[](`0``0;_]V`0```",``+5___RQT`1AA-`DH7SD!"`(@@R@_X(`?_>`
MH&`!&$``_"<``#`#```@I`R`$X"D@`$R0`#R$0``5L($(`S&`$``P@#@"("(
M9``"0`!:A`A@_X"@H`0(0`"Y@*"@"P)``*6`H*`,`D``G8((0!.`H$`2`D``
M0H0`O_?0`.`,0`!<I]($883F!"`(Q`1AA*00``B"#.#_@@!_]X"@8`$80`";
MX@"``"D``#`#```@I@S`%("DP`$R0`!F$0``5L($(`S&`$``Q`#@"("(I``"
M0`!,@@B@_X"@8`0(0`">@*!@"P)``'B`H&`,`D``<(0(@!2`H(`3$D``!8(`
M?_>`H&`!*$``)Q$``%;4`.`,$0``5I(0`!&0$B/80`!<O)80`!)``%S;`0``
M`$``7$;0`@``P@0@"(0(8/^$`+_W@*"@`1A``*$%```P@@A``@4``""`H$`"
M$D``<P,``+7$!"`,P@!AA-(`@`!___=_U`!``!!O_SR0$"``@*"@`3A/_\#0
M`.`,$0``5A,``%:0$B$XDA)C&$``7)V4$"!L$P``5I`2(3B2$F,80`!<F)00
M(&Y``%RWD!`@`$``7"+0`@``P@0@"(0(8/^$`+_W@*"@`1A``(^""$`3@*!`
M$A)``(:4$"``P@0@#)80(`)``%S`T@!``!!O_Z(!````0`!<I)`0(`!``%P/
MT`(``,($(`B$"&#_A`"_]X"@H`$80``[@@A`%("@0!,20``(EA`@`L($(`R4
M$"``0`!<K=(`0``0;_^SE!``"!$``%83``!6D!(A.)(28=A``%QLE!`@;A$`
M`%83``!6D!(A.)(28NA``%QFE!`@(A$``%83``!6D!(A.)(28KA``%Q@E!`@
M(A$``%83``!6D!(A.)(28HA``%Q:E!`@(A$``%83``!6D!(A.)(28NA``%Q4
ME!`@;A$``%83``!6D!(A.)(28KA``%Q.E!`@;A$``%83``!6D!(A.)(28NA`
M`%Q(E!`@;!$``%83``!6D!(A.)(28KA``%Q"E!`@;!$``%83``!6D!(A.)(2
M87!``%P\E!`@;A$``%83``!6D!(A.)(28=A``%PVE!`@/!$``%83``!6D!(A
M.)(28HA``%PPE!`@;!$``%83``!6D!(A.)(28HA``%PJE!`@;A$``%83``!6
MD!(A.)(287!``%PDE!`@'A$``%83``!6D!(A.)(287!``%P>E!`@,A,``%:0
M$B$XDA)AV$``7!F4$"`P$0``5]0$H7S"`&&$D!(@"$``7!/2`$``$0``5A,`
M`%:0$B$XDA)A<$``7`V4$"`\$0``5A,``%:0$B$XDA)AV$``7`>4$"`X$0``
M5A,``%:0$B$XDA)AV$``7`&4$"!L$0``5A,``%:0$B$XDA)A<$``6_N4$"!L
M$0``5A,``%:0$B$XDA)A<$``6_64$"`X$0``5A,``%:0$B$XDA)A<$``6^^4
M$"`P$P``5I`2(3B2$F'80`!;ZI00(#(1``!6$P``5I`2(3B2$F'80`!;Y)00
M(!X!````G>._H)`0(`!``%P`,P``5]`"```U``"P-P``5[(68%A``%MGM!:C
M#+`0``@0@%OQE^[@>`$````!`````0```)WCOZ"0$"``0`!;\#<``%70`@``
MMA;CX#,``%<U``!20`!;5[H0(`!____FLA9@B$``6^:0$"``T`(``+06H\!`
M`%M/N!``&Q"`6W>1Z``(`0```#!H``,!`````0```('#X`BN`\`7,&@`!@$`
M```!`````0````$````!````G>._H`,````O``!:?___]:X%XYB"$&`(P@7`
M`8"@8``"0``#MA`@`/8`0``0@%L9@>@```$````!`````0```('#X`@!````
M@</@"*X#P!<P:``$`0````$````!````G>._H"\``%I____XK@7C/$``6\@!
M````!0````,```""$&`0A!"@#.(%P`'D!<`"I"2`$8,\H!^!@&``I/R@!`)`
M``N@$"``P@1``)`0`!B2$``9E!``&I_`0`"@!"`!@*0`$@I/__FB!&`$@<_@
M"`$````P:``#`0````$```"=X[^@(0``L*`4(`3"!#_\@*!__P)```B@!#_\
MG\!``*`$/_S"!```@*!__Q)/__P!````@<_@"`$````!````G>._H('/X`@!
M````,&@`!0$````!`````0````$```"=X[^@?__PCP$```"!Q^`(@>@`````
M`````@`!`````%!!4E]#3$5!3@`````````O<')O8R]S96QF+V5X90``+@``
M```````N+@```````"5S+R5S````+W!R;V,O)6DO)7,``````&5X90``````
M3$1?3$E"4D%265]0051(`$Q)0E!!5$@`3$E"4D%265]0051(`````$193$1?
M3$E"4D%265]0051(`````````"5S)7,E<P``4$%27TE.251)04Q)6D5$`%!!
M4E]34$%73D5$``````!005)?5$5-4```````````4$%27T1%0E5'````````
M`%!!4E]#04-(10````````!005)?4%)/1TY!344`````4$%27T%21T,`````
M`````%!!4E]!4D=67S````````!005)?1TQ/0D%,7T1%0E5'``````````!0
M05)?1TQ/0D%,7U1-4$1)4@````````!005)?5$U01$E2````````4$%27T=,
M3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X``````````%!!4E]#3$5!3CT`
M```````Q`````````'!A<BT`````+64````````M+0```````$,Z7%1%35``
M+W1M<`````!435!$25(``%1%35!$25(`5$5-4`````!435```````%5315(`
M````55-%4DY!344``````````"5S)7,E<R5S```````````E<R5S8V%C:&4M
M)7,E<P``)3`R>``````E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E
M<P``````````4UE35$5-``!!4D=6`````$%S<V5R=&EO;B`E<R!F86EL960Z
M(&9I;&4@(FEN=&5R;F%L<RYC(BP@;&EN92`E9```````````*"AS=G1Y<&4I
M*"AS:'!L97`I+3YS=E]F;&%G<R`F(#!X9F8I*2`]/2!35G1?4%9'5B!\?"`H
M*'-V='EP92DH*'-H<&QE<"DM/G-V7V9L86=S("8@,'AF9BDI(#T](%-6=%]0
M5DQ6```H*"@H<VAP;&5P*2T^<W9?9FQA9W,@)B`H,'@P,#`P-#`P,'PP>#`P
M,#`X,#`P*2D@/3T@,'@P,#`P.#`P,"D@)B8@*"@H<W9T>7!E*2@H<VAP;&5P
M*2T^<W9?9FQA9W,@)B`P>&9F*2D@/3T@4U9T7U!61U8@?'P@*"AS=G1Y<&4I
M*"AS:'!L97`I+3YS=E]F;&%G<R`F(#!X9F8I*2`]/2!35G1?4%9,5BDI````
M`"@H<W9T>7!E*2@H7W-V:2DM/G-V7V9L86=S("8@,'AF9BDI(#X](%-6=%]0
M5@```"@H<W9T>7!E*2@H7W-V:2DM/G-V7V9L86=S("8@,'AF9BDI("$](%-6
M=%]05D%6`"@H<W9T>7!E*2@H7W-V:2DM/G-V7V9L86=S("8@,'AF9BDI("$]
M(%-6=%]05DA6`"$H*"@H7W-V:2DM/G-V7V9L86=S("8@*#!X,#`P,#0P,#!\
M,'@P,#`P.#`P,"DI(#T](#!X,#`P,#@P,#`I("8F("@H*'-V='EP92DH*%]S
M=FDI+3YS=E]F;&%G<R`F(#!X9F8I*2`]/2!35G1?4%9'5B!\?"`H*'-V='EP
M92DH*%]S=FDI+3YS=E]F;&%G<R`F(#!X9F8I*2`]/2!35G1?4%9,5BDI`!@`
M````````<&5R;``````P`````````"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I
M;&5D("T@86)O<G1I;F<@=VET:"`E:2X*`"5S.B!C<F5A=&EO;B!O9B!P<FEV
M871E('1E;7!O<F%R>2!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("T@86)O<G1I
M;F<@=VET:"`E:2X*````1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R````
M``!P97)L>'-I+F,`````````26YT97)N86QS.CI005(Z.D)/3U0`````+P``
M```````Z`````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M```````!7*```5RH````````````````0<____^```!P87(N<&P``",A+W5S
M<B]B:6XO<&5R;`H*979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D
M>S$K(B1`(GTG"B`@("!I9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@
M<VAE;&P*"G!A8VMA9V4@7U]P87)?<&P["@HC("TM+2!4:&ES('-C<FEP="!M
M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@870@8V]M<&EL92!T:6UE("TM+0HC
M('5S92!S=')I8W0["@HC;&EN92`Q-3D*"FUY("@D<&%R7W1E;7`L("1P<F]G
M;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2![
M"B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.D)A
M<V5N86UE.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["B`@("!O
M=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["B`@("!&
M:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U
M;FQI;FL@?2P@)'!A<E]T96UP*3L*("`@(')M9&ER("1P87)?=&5M<#L*("`@
M(",@1&]N)W0@<F5M;W9E('1O<&1I<B!B96-A=7-E('1H:7,@8V%U<V5S(&$@
M<F%C92!W:71H(&]T:&5R(&%P<',*("`@(",@=&AA="!A<F4@=')Y:6YG('1O
M('-T87)T+@H*("`@(&EF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I
M;C,R)RD@>PH@("`@("`@(",@4V]M971H:6YG('=E;G0@=W)O;F<@=6YL:6YK
M:6YG('1H92!T96UP;W)A<GD@9&ER96-T;W)Y+B`@5&AI<PH@("`@("`@(",@
M='EP:6-A;&QY(&AA<'!E;G,@;VX@<&QA=&9O<FUS('1H870@9&ES86QL;W<@
M=6YL:6YK:6YG('-H87)E9`H@("`@("`@(",@;&EB<F%R:65S(&%N9"!E>&5C
M=71A8FQE<R!T:&%T(&%R92!I;B!U<V4N(%5N;&EN:R!W:71H(&$@8F%C:V=R
M;W5N9`H@("`@("`@(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@9FEL97,@87)E
M(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI<R!P<F]C97-S+@H@("`@("`@(",@
M1&]N)W0@9&\@86YY=&AI;F<@;VX@5VEN9&]W<R!B96-A=7-E(&]U<B!P87)E
M;G0@<')O8V5S<R!W:6QL"B`@("`@("`@(R!T86ME(&-A<F4@;V8@8VQE86YI
M;F<@=&AI;F=S('5P+@H*("`@("`@("!M>2`D=&UP(#T@;F5W($9I;&4Z.E1E
M;7`H"B`@("`@("`@("`@(%1%35!,051%(#T^("=T;7!86%A86"<L"B`@("`@
M("`@("`@($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER
M*2P*("`@("`@("`@("`@4U5&1DE8(#T^("<N8VUD)RP*("`@("`@("`@("`@
M54Y,24Y+(#T^(#`L"B`@("`@("`@*3L*"B`@("`@("`@<')I;G0@)'1M<"`B
M(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"B`@(')M
M("UR9B`G)'!A<E]T96UP)PH@("!I9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[
M('1H96X*("`@("`@(&)R96%K"B`@(&9I"B`@('-L965P(#$*("`@>#U@97AP
M<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB
M.PH@("`@("`@("`@("!C:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PH@("`@
M("`@(&UY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R
M/B8Q("8G.PH@("`@("`@(&-L;W-E("1T;7`["B`@("`@("`@<WES=&5M*"1C
M;60I.PH@("`@("`@(&]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E
M<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"B`@("`@("`@("`@("`N("1T;7`M
M/F9I;&5N86UE*3L*("`@('T*?2!]"@I"14=)3B!["B`@("!);G1E<FYA;',Z
M.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M.PH*("`@(&5V86P@>PH*7W!A<E]I;FET7V5N=B@I.PH*:68@*&5X:7-T<R`D
M14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PH@("`@
M0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM0
M05)?05)'0WT@+2`Q*3L*("`@("0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE
M;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6*2!["B`@("`@("`@9&5L971E("1%
M3E9[)%]](&EF("]>4$%27T%21U9?+SL*("`@('T*?0H*;7D@)'%U:65T(#T@
M(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX("1P<F]G;F%M92!I9B!I;G9O:V5D
M(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@*`H@("`@<&%T:%]S97`@("`@/3X@
M*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"B`@("!?97AE("`@("`@
M("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G
M(#H@)R<I+`H@("`@7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S971?<')O9VYA;64H*3L*7W-E=%]P
M87)?=&5M<"@I.PH*(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@86YD(&5X=')A
M8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[>PIM>2`H)'-T87)T7W!O<RP@)&1A
M=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT[
M"@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L(&=E="!S=&%R="!O9B!D871A('-E
M8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S
M=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@("!M>2`D8G5F.PH@("`@<V5E:R!?
M1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#@["B`@("!L87-T('5N
M;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*"B`@("!S965K(%]&2"P@+3$R
M+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!S965K(%]&2"P@+3$R
M("T@=6YP86-K*").(BP@)&)U9BDL(#(["B`@("!R96%D(%]&2"P@)&)U9BP@
M-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*("`@(",@?7U]
M"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@9FEL92!I;G1O(&UE;6]R>2![>WL*
M("`@(&UY("5R97%U:7)E7VQI<W0["B`@("!W:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&UY("1F
M=6QL;F%M92`]("1B=68["B`@("`@("`@;W5T<RAQ<2A5;G!A8VMI;F<@9FEL
M92`B)&9U;&QN86UE(BXN+BDI.PH@("`@("`@(&UY("1C<F,@/2`H("1F=6QL
M;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["B`@
M("`@("`@;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ
M+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*
M("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@
M("`@("`@(&EF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M
M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&9I;&5N
M86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*("`@("`@("`@("`@:68@
M*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@
M("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@("`@("!C
M;&]S92`D;W5T.PH@("`@("`@("`@("`@("`@8VAM;V0@,#<U-2P@)&9I;&5N
M86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*("`@("`@("`@("`@
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE
M.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO
M/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["B`@("`@
M("`@("`@(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL92@I"B`@("`@
M("`@("`@(&UY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA
M;64D97AT(CL*("`@("`@("`@("`@;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN
M(BD["B`@("`@("`@("`@(&]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@
M;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@
M("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@(&-L;W-E("1O=70[
M"B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D<F5Q=6ER
M95]L:7-T>R1F=6QL;F%M97T@/0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ
M36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*("`@("`@("`@("`@("`@(&)U
M9B`]/B`D8G5F+`H@("`@("`@("`@("`@("`@8W)C(#T^("1C<F,L"B`@("`@
M("`@("`@("`@("!N86UE(#T^("1F=6QL;F%M92P*("`@("`@("`@("`@?3L*
M("`@("`@("!]"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!]"B`@
M("`C('U]?0H*("`@(&QO8V%L($!)3D,@/2`H<W5B('L*("`@("`@("!M>2`H
M)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@("`@("`@(')E='5R;B!I9B!R968@
M)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@("`@("`@;7D@)&9I;&5N86UE(#T@
M9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PH@("`@("`@
M("`@("!M>2`D:V5Y.PH@("`@("`@("`@("!F;W)E86-H("AK97ES("5R97%U
M:7)E7VQI<W0I('L*("`@("`@("`@("`@("`@(&YE>'0@=6YL97-S("]<421M
M;V1U;&5<120O.PH@("`@("`@("`@("`@("`@)&ME>2`]("1?.R!L87-T.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1K97E](&EF(&1E9FEN960H)&ME>2D["B`@("`@("`@?2!O<B!R971U<FX[
M"@H@("`@("`@("1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O
M)&UO9'5L92(["@H@("`@("`@(&EF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E
M9FEN960H)DE/.CI&:6QE.CIN97<I*2!["B`@("`@("`@("`@(&UY("1F:"`]
M($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["B`@("`@("`@("`@
M(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<')I;G0@)&9H("1F:6QE;F%M
M92T^>V)U9GT["B`@("`@("`@("`@('-E96LH)&9H+"`P+"`P*3L*("`@("`@
M("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@
M("`@("`@("`@(&UY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L
M("1F:6QE;F%M92T^>V-R8WTI.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@
M("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@
M('!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@("`@
M(&-L;W-E("1O=70["B`@("`@("`@("`@('T*("`@("`@("`@("`@;W!E;B!M
M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM
M;V1E*"1F:"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H*
M("`@("`@("!D:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN
M9"`D;6]D=6QE(5QN(CL*("`@('TL($!)3D,I.PH*("`@(",@3F]W(&QO860@
M86QL(&)U;F1L960@9FEL97,@>WM["@H@("`@(R!I;FET:6%L:7IE('-H87)E
M9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@
M(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD[
M"B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(%!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@("`C(&YO=R!L970G<R!T<GD@9V5T
M=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M('=I=&AI;@H@("`@<F5Q=6ER92!)
M3SHZ1FEL93L*"B`@("`C(&QO860@<F5S="!O9B!T:&4@9W)O=7`@:6X*("`@
M('=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI
M<W0I6S!=*2!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&
M24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!U;FQE<W,@*"1)
M3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*("`@
M("`@("`@("`@(R!R97%U:7)E(&UO9'5L97,L(&1O(&]T:&5R(&5X96-U=&%B
M;&4@9FEL97,*("`@("`@("`@("`@:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_
M)"]I*2!["B`@("`@("`@("`@("`@("!R97%U:7)E("1F:6QE;F%M93L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@
M(",@4VMI<"!!8W1I=F53=&%T92=S('-I=&5C=7-T;VUI>F4N<&P@9FEL93H*
M("`@("`@("`@("`@("`@(&1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE
M(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T[
M"B`@("!]"@H@("`@(R!]?7T*"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")0
M2UPP,#-<,#`T(CL*("`@("1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*
M?0HC('U]?0H*(R!!<F=U;65N="!P<F]C97-S:6YG('M[>PIM>2!`<&%R7V%R
M9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*
M"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*"B,@1&]N)W0@
M<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I
M=&AO=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=6
M6S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D
M:7-T7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@
M(&D@("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@
M("`@("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@
M("D["@H@("`@;7D@0&%D9%]T;U]I;F,["B`@("!W:&EL92`H0$%21U8I('L*
M("`@("`@("`D05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI
M+R!O<B!L87-T.PH*("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@("`@("`@
M("`@('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@("`@('T*("`@("`@("!E
M;'-I9B`H)#$@97$@)TTG*2!["B`@("`@("`@("`@(&5V86P@(G5S92`D,B([
M"B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G02<I('L*("`@("`@
M("`@("`@=6YS:&EF="!`<&%R7V%R9W,L("0R.PH@("`@("`@('T*("`@("`@
M("!E;'-I9B`H)#$@97$@)T\G*2!["B`@("`@("`@("`@("1O=70@/2`D,CL*
M("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=B)RD@>PH@("`@("`@
M("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@("`@('T*("`@("`@("!E;'-I
M9B`H)#$@97$@)T(G*2!["B`@("`@("`@("`@("1B=6YD;&4@/2`G86QL)SL*
M("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=Q)RD@>PH@("`@("`@
M("`@("`D<75I970@/2`Q.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@
M97$@)TPG*2!["B`@("`@("`@("`@(&]P96X@)&QO9V9H+"`B/CXB+"`D,B!O
M<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["B`@("`@("`@?0H@
M("`@("`@(&5L<VEF("@D,2!E<2`G5"<I('L*("`@("`@("`@("`@)&-A8VAE
M7VYA;64@/2`D,CL*("`@("`@("!]"@H@("`@("`@('-H:69T*$!!4D=6*3L*
M"B`@("`@("`@:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["B`@("`@
M("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@("`@("`@("!I
M;FET7VEN8R@I.PH@("`@("`@("`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@
M("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%2
M1U8["B`@("`@("`@("`@(&5X:70["B`@("`@("`@?0H@("`@?0H*("`@('5N
M<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*"B,@6%A8("TM(&%D9"`M+7!A
M<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T(&UO9&4@*"U/*2!H
M86YD;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*("`@("`@("`C;&]C86P@
M)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G
M.PH@("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@("`@<F5Q=6ER92!!
M<F-H:79E.CI::7`["B`@("!]"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6
M*3L*("`@(&UY("1Z:7`["@H*("`@(&EF("AD969I;F5D("1P87(I('L*("`@
M("`@("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I
M;F0@)R1P87(G.B`D(2(["B`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@
M(&)L97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@
M("`@("`@("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@
M('T*"@H@("`@;7D@)65N=B`](&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@
M("`@("`@("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@("`@("`@("1M971A(#U^("]>
M("`H6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@
M3W!E;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@
M/2!<-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!0
M05(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM
M;V1E*%!!4BD["B`@("`@("`@9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE
M(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R
M96%T95!A=&@H)&]U="D@.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W*`H@("`@("`@("1O=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H
M*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H
M*2P*("`@("`@("`P-S<W+`H@("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E
M*"1F:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A
M7W!O<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A
M9&5R(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)
M37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@
M('T*("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@
M("`@("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V
M86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY
M("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@
M("`@("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@
M("`@("`@("1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@
M)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D
M<V5T*2DI"B`@("`@("`@?65G.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A
M9&5R*3L*("`@("0O(#T@=6YD968["B`@("`C('U]?0H*("`@(",@5W)I=&4@
M8G5N9&QE9"!M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@
M("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PH@("`@("`@(&EN:71?:6YC*"D["@H@("`@("`@
M(')E<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`:6YC(#T@<V]R="![
M"B`@("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T:"@D82D*("`@("`@
M("!](&=R97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*("`@("`@("!](&=R
M97`@>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G<VET92<I(&]R"B`@("`@
M("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD
M"B`@("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X
M<'TI.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@:68@*"1#;VYF:6=[7V1E
M;&EM?2!E<2`G7%PG*2![('-[7%Q]>R]]9R!F;W(@0&EN8R!]"@H@("`@("`@
M(",@1FEL92!E>&ES=',@=&5S="!A9&1E9"!T;R!F:7@@4E0@(S0Q-SDP.@H@
M("`@("`@(",@1G5N;GDL(&YO;BUE>&ES=&EN9R!E;G1R>2!I;B!?/"XN+BYA
M=71O+T-O;7!R97-S+U)A=R]:;&EB+V%U=&]S<&QI="YI>"X*("`@("`@("`C
M(%1H:7,@:7,@82!B86YD+6%I9"!F:7@@=VET:"!N;R!D965P97(@9W)A<W`@
M;V8@=&AE(&ES<W5E+@H@("`@("`@(",@4V]M96)O9'D@<&QE87-E(&=O('1H
M<F]U9V@@=&AE('!A:6X@;V8@=6YD97)S=&%N9&EN9R!W:&%T)W,@:&%P<&5N
M:6YG+`H@("`@("`@(",@22!F86EL960N("TM(%-T969F96X*("`@("`@("!M
M>2`E9FEL97,["B`@("`@("`@+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F
M:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK
M(&9O<B!V86QU97,@)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N
M9FEG.CI#;VYF:6=[;&EB7V5X='T["B`@("`@("`@;7D@)7=R:71T96X["@H@
M("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@
M("`@;7D@*"1N86UE+"`D9FEL92D["@H@("`@("`@("`@("!F;W)E86-H(&UY
M("1D:7(@*$!I;F,I('L*("`@("`@("`@("`@("`@(&EF("@D;F%M92`]("10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@
M("`@)&9I;&4@/2`D7SL*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I
M<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PH@("`@("`@("`@("`@("`@("`@("@D
M9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["B`@("`@("`@("`@("`@("`@("`@
M;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF
M("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@
M("`@("`@("`@(&EF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A
M8VAE>R0Q?2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N
M86UE*2`]("@D<F5F+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA
M<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M(&5L<VEF("@M9B`B)&1I<B\D,2(I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@
M("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!N
M97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA
M;65]*RL["B`@("`@("`@("`@(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PH@("`@("`@("`@("!O=71S*"!J
M;VEN("(B+`H@("`@("`@("`@("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F
M:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@
M<7$H(BXN+BD*("`@("`@("`@("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT
M96YT.PH@("`@("`@("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@
M("`@("`@)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!O<&5N($9)3$4L
M("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@
M("`@("`@("`@("`@("!B:6YM;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@
M)&-O;G1E;G0@/2`\1DE,13X["B`@("`@("`@("`@("`@("!C;&]S92!&24Q%
M.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0H@("`@("`@("`@("`@("`@("`@
M(&EF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M
M?&EX?&%L*20O:3L*"B`@("`@("`@("`@("`@("`C($1O(&YO="!L970@6%-,
M;V%D97(@<&EC:R!U<"!A=71O+RH@9G)O;2!E;G9I<F]N;65N=`H@("`@("`@
M("`@("`@("`@)&-O;G1E;G0@/7X@<R]G;W1O("MR971R>2`K=6YL97-S("LN
M*B]G;W1O(')E=')Y.R\*("`@("`@("`@("`@("`@("`@("!I9B!L8R@D;F%M
M92D@97$@;&,H(EA33&]A9&5R+G!M(BD["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@
M("`@("1F:"T^<')I;G0H(D9)3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN
M="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@
M)&9H+3YP<FEN="AS<')I;G1F*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M"B`@("`@("`@("`@("DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH
M)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I
M;G0H)&-O;G1E;G0I.PH@("`@("`@('T*("`@('T*("`@(",@?7U]"@H@("`@
M(R!.;W<@=W)I=&4@;W5T('1H92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM[
M"B`@("`D>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@
M("`@)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@
M("`@:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U
M="DI6SE=*2!["B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M
M/FYE=R!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N
M9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@
M("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)3
M24].('T@?'P@,#L*("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X
M)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C
M='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM
M>2`D9F@L("(\)&]U="(I*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F
M:"D["B`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@
M("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`D8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E
M<W0@.B`D;71I;64["B`@("!]"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@
M*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*("`@("1C86-H95]N86UE("X]
M(")#04-(12(["B`@("`D9F@M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F
M:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R
M*2DI.PH@("`@)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC
M;&]S93L*("`@(&-H;6]D(#`W-34L("1O=70["B`@("`C('U]?0H*("`@(&5X
M:70["GT*(R!]?7T*"B,@4')E<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL
M92!C86-H92![>WL*>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?
M<&]S.PH*("`@(%]F:7A?<')O9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H
M92!005(@9FEL92!A;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*
M("`@(')E<75I<F4@4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PH*"B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=]
M(#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U
M:7)E($9I;&4Z.D9I;F0["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`[
M"B`@("!]"B`@("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO
M*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB
M0V%C:&4L("1Z:7`["B`@("`D4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@
M)'II<#L*"B`@("`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T
M<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@
M("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@
M<V5T(&%T('1H:7,@<&]I;G0A"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*("`@("`@("`@("`@;F5X="!I9B`D;65M
M8F5R+3YI<T1I<F5C=&]R>3L*("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE
M(#T@)&UE;6)E<BT^9FEL94YA;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S
M("1M96UB97)?;F%M92`]?B!M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@
M("`@("`@("`@+S]S:&QI8B\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z
M.D-O;F9I9WMV97)S:6]N?2\I/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK
M*0H@("`@("`@("`@("`@("`@)`H@("`@("`@("`@("!]>#L*("`@("`@("`@
M("`@;7D@)&5X=')A8W1?;F%M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S
M=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@
M)&5X=')A8W1?;F%M92D["B`@("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE
M("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@
M("`@("`@("`@("`@("!O=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%
M>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@
M("`@("`@("`@("`@("`@)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D
M97-T7VYA;64I.PH@("`@("`@("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?
M;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*("`@(",@?7U]"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M
M86EN+G!L('1O(')U;BP@<VAO=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,
M:6)#86-H97LD<')O9VYA;65]*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`
M05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM
M;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*
M(R!]?7T*"G-U8B!#<F5A=&50871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*
M("`@(`H@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S
M96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R
M<V4H)&YA;64L("@G7"XN*B<I*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0
M871H.PH@("`@"B`@("!&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@
M<F5Q=6ER95]M;V1U;&5S('L*("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`]
M(%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L
M:6(["B`@("!R97%U:7)E($1Y;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G
M97(["B`@("!R97%U:7)E('-T<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,[
M"B`@("!R97%U:7)E('9A<G,["B`@("!R97%U:7)E($-A<G`["B`@("!R97%U
M:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%<G)N;SL*("`@(')E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@
M(')E<75I<F4@1F-N=&P["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R
M97%U:7)E($9I;&4Z.E-P96,["B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@
M<F5Q=6ER92!#;VYF:6<["B`@("!R97%U:7)E($E/.CI(86YD;&4["B`@("!R
M97%U:7)E($E/.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*
M("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!005(["B`@
M("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*
M("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@979A;"![
M(')E<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@
M("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["B`@("!E=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*("`@(&5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["GT*"B,@5&AE($,@
M=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I
M<BYC"B,@5&AI<R!C;V1E(&%L<V\@;&EV97,@:6X@4$%2.CI3971U<%1E;7`@
M87,@<V5T7W!A<E]T96UP7V5N=B$*<W5B(%]S971?<&%R7W1E;7`@>PH@("`@
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@
M(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H(&UY("1P871H("@*("`@("`@
M("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*
M("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD
M("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@("`@("!M>2`D=7-E<FYA;64[
M"B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@(",@9&]E<R!N;W0@=V]R:R!E
M=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H
M)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@("`@:68@*"!D969I;F5D*"97
M:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@
M)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("AD
M969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D<'=U
M:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D=7-E
M<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-4
M14TG.PH@("`@("`@('T*("`@("`@("`D=7-E<FYA;64@/7X@<R]<5R]?+V<[
M"@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]
M<&%R+21U<V5R;F%M92(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"B`@("`@("`@:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@("`@("`@("`@(&]P96X@*&UY
M("1F:"P@(CPB+B`D<')O9VYA;64I.PH@("`@("`@("`@("!S965K("1F:"P@
M+3$X+"`R.PH@("`@("`@("`@("!S>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*
M("`@("`@("`@("`@:68@*"1B=68@97$@(EPP0T%#2$4B*2!["B`@("`@("`@
M("`@("`@("!S965K("1F:"P@+34X+"`R.PH@("`@("`@("`@("`@("`@<WES
M<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@("`@("`@("`@("`@)&)U9B`]?B!S
M+UPP+R]G.PH@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@
M("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@("`@("`@("!\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE
M=R!].PH*("`@("`@("`@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN
M($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("`@("`@("`@(&UY
M("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@
M?2!\?"`P.PH@("`@("`@("`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G
M-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@
M("`@("`@("`@("1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D
M8W1X*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F
M:"P@(CPD<')O9VYA;64B*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!B
M:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@("1C='@M/F%D
M9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@8VQO<V4H)&9H
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A
M8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@
M('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)$5.5GM005)?0TQ%04Y]
M(#T@,3L*("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?71E;7`M)"0B.PH@("`@("`@('T*"B`@("`@("`@)$5.5GM005)?5$5-4'T@
M/2`D<W1M<&1I<CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@
M("`@("!L87-T.PH@("`@?0H*("`@("1P87)?=&5M<"`]("0Q(&EF("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*"G-U
M8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L("1C<F,I(#T@0%\["B`@("!M
M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@("1F:6QE;F%M92`]("(D<&%R7W1E
M;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@
M("`@("!U;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*("`@("`@
M("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64["B`@("!]"B`@("!E;'-E('L*
M("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL
M96YA;64I.PH@("`@?0H*("`@(&]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O
M<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["B`@("!R971U<FXH)&9H+"`D
M9FEL96YA;64I.PI]"@HC('-A;64@8V]D92!L:79E<R!I;B!005(Z.E-E='5P
M4')O9VYA;64Z.G-E=%]P<F]G;F%M90IS=6(@7W-E=%]P<F]G;F%M92!["B`@
M("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*("`@("`@("`D<')O9VYA;64@/2`D
M,3L*("`@('T*"B`@("`D<')O9VYA;64@?'P]("0P.PH*("`@(&EF("@D14Y6
M>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0
M?2D@/CT@,"D@>PH@("`@("`@("1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA
M;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*
M("`@('T*"B`@("!I9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@(&EF
M("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*("`@("`@("`@("`@
M<F5T=7)N(&EF("US("1F:#L*("`@("`@("!]"B`@("`@("`@:68@*"US("(D
M<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@("`@("`@("`@("`D<')O9VYA
M;64@+CT@)$-O;F9I9WM?97AE?3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@
M("`@('T*("`@('T*"B`@("!F;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#
M;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["B`@("`@("`@;F5X
M="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM0
M05)?5$5-4'T["B`@("`@("`@)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]
M7$4D+R\["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*("`@("`@("`@
M("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG
M>U]E>&5](CL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*?0H*<W5B(%]F
M:7A?<')O9VYA;64@>PH@("`@)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%2
M7U!23T=.04U%?3L*("`@(&EF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@/"`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@(BXD0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0H*("`@(",@6%A8("T@:&%C:R!T
M;R!M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@("`@("`@("`@("`@(#H@*"AD
M969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P
M=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@)'!R;V=N86UE(#U^(',O7B@_
M/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM
M?2\["@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"@IS
M=6(@7W!A<E]I;FET7V5N=B!["B`@("!I9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["B`@("`@("`@<F5T=7)N.PH@("`@?2!E;'-E('L*
M("`@("`@("`D14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PH@("`@?0H*("`@
M(&9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'
M3D%-12!!4D=#($%21U9?,"`I("D@>PH@("`@("`@(&1E;&5T92`D14Y6>R=0
M05)?)RXD7WT["B`@("!]"B`@("!F;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B`@("`@("`@)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??3L*("`@('T*"B`@("!M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#
M3$5!3E]?("`@("`@("`@("`@("`@(CL*"B`@("!I9B`H)$5.5GM005)?5$5-
M4'TI('L*("`@("`@("!D96QE=&4@)$5.5GM005)?0TQ%04Y].PH@("`@?0H@
M("`@96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PH@
M("`@("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE
M;F=T:"@B0TQ%04XB*2D["B`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@)#$@
M:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*("`@('T*?0H*<W5B
M(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE=#L*("`@(&EF("@D;&]G9F@I
M('L*("`@("`@("!P<FEN="`D;&]G9F@@(D!?7&XB.PH@("`@?0H@("`@96QS
M92!["B`@("`@("`@<')I;G0@(D!?7&XB.PH@("`@?0I]"@IS=6(@:6YI=%]I
M;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!P=7-H($!)3D,L(&=R97`@
M9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`H@("`@("`@
M(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP
M"B`@("`@("`@=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*("`@("D["GT*
M"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PHC(%1H92!M86EN('!A8VMA
M9V4@9F]R('-C<FEP="!E>&5C=71I;VX*"G!A8VMA9V4@;6%I;CL*"G)E<75I
M<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI
M;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@
M<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E
M8W1O<GE<;BD*("`@('5N;&5S<R`M92`D<')O9VYA;64["@ID;R`D<')O9VYA
M;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D0"!I9B`D0#L*"GT["@HD.CI?7T524D]2(#T@)$`@:68@
M)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/
M4CL*"C$["@HC;&EN92`Q,#`R"@I?7T5.1%]?"@````$;`SL```#H````'/__
M8Y@```$`__]C^````1S__W=X```!./__>%@```%4__]X>````7#__WC8```!
MC/__>3@```&H__]Z6````<3__WJX```!X/__?-@```'X__]^>````A3__W\X
M```"+/__@!@```)(__^`.````ES__X)X```">/__@[@```*4__^%6````K#_
M_X68```"R/__AQ@```+D__^'V````OS__XIX```#&/__C)@```,T__^56```
M`U#__YY8```#:/__GI@```.$__^?&````Z#__Y]8```#O/__GW@```/0````
M$``````!>E(`!'P/`1L,#@`````8````&/__8I````!0`$$-'BU3"0\?````
M````&````#3__V+4```3:`!!#1XM:PD/'P```````!@```!0__]V.````.``
M00T>+44)#Q\````````8````;/__=OP````8`$$-'BU!"0\?````````&```
M`(C__W<`````8`!!#1XM10D/'P```````!@```"D__]W1````%0`00T>+40)
M#Q\````````8````P/__=X@```$<`$$-'BU+"0\?````````&````-S__WB,
M````1`!!#1XM00D/'P```````!0```#X__]XT````@P`00T>+0D/'P```!@`
M``$0__]ZV````9@`00T>+4,)#Q\````````4```!+/__?%P```"T`$$-'BT)
M#Q\````8```!1/__?00```#4`$,-'BU$"0\?````````$````6#__WW(````
M$``````````8```!=/__?=0```(L`$$-'BU$"0\?````````&````9#__W_X
M```!0`!!#1XM6`D/'P```````!@```&L__^!'````:``00T>+5,)#Q\`````
M```4```!R/__@J`````H`$$-'BT)#Q\````8```!X/__@L@```&``$$-'BU#
M"0\?````````%````?S__X0L````L`!!#1XM"0\?````&````A3__X34```"
MD`!!#1XM10D/'P```````!@```(P__^'6````B``00T>+44)#Q\````````8
M```"3/__B5P```BP`$,-'BUN"0\?````````%````FC__Y(````)``!!#1XM
M"0\?````&````H#__YKH````.`!!#1XM00D/'P```````!@```*<__^;#```
M`%0`00T>+4$)#Q\````````8```"N/__FW`````X`$$-'BU$"0\?````````
M$````M3__YN4````"``````````8```"Z/__FZ````!T`$$-'BU#"0\?````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````_____P````#_____```````````````!`````0````$`
M``*M`````0```KP````!```"R`````$```+3`````0```MT````!```"ZP``
M``$```+X`````0```T<````/```$K0````P``1AD````#0`!5L!O__[U``$!
MC`````4``0R0````!@`!!6`````*```&5`````L````0````%0`````````#
M``+!.`````(```/,````%`````<````7``$4D`````<``11L````"````_``
M```)````#&____X``1/,;____P````)O___P``$2Y```````````````````
M```````````````````````````````````````````````"P!0```````%6
MW``"P````L``````````````````````````````````````````````````
M`````````````````P``,#"___,!`````P``/#"___`!`````P``2#"__^T!
M`````P``5#"__^H!`````P``8#"__^<!`````P``;#"__^0!`````P``>#"_
M_^$!`````P``A#"__]X!`````P``D#"__]L!`````P``G#"__]@!`````P``
MJ#"__]4!`````P``M#"__](!`````P``P#"__\\!`````P``S#"__\P!````
M`P``V#"__\D!`````P``Y#"__\8!`````P``\#"__\,!`````P``_#"__\`!
M`````P`!"#"__[T!`````P`!%#"__[H!`````P`!(#"__[<!`````P`!+#"_
M_[0!`````P`!.#"__[$!`````P`!1#"__ZX!`````P`!4#"__ZL!`````P`!
M7#"__Z@!`````P`!:#"__Z4!`````P`!=#"__Z(!`````P`!@#"__Y\!````
M`P`!C#"__YP!`````P`!F#"__YD!`````P`!I#"__Y8!`````P`!L#"__Y,!
M`````P`!O#"__Y`!`````P`!R#"__XT!`````P`!U#"__XH!`````P`!X#"_
M_X<!`````P`![#"__X0!`````P`!^#"__X$!`````P`"!#"__WX!`````P`"
M$#"__WL!`````P`"'#"__W@!`````P`"*#"__W4!`````P`"-#"__W(!````
M`P`"0#"__V\!`````P`"3#"__VP!`````P`"6#"__VD!`````P`"9#"__V8!
M`````P`"<#"__V,!`````P`"?#"__V`!`````P`"B#"__UT!`````P`"E#"_
M_UH!`````P`"H#"__U<!`````P`"K#"__U0!`````P`"N#"__U$!`````P`"
MQ#"__TX!`````P`"T#"__TL!`````P`"W#"__T@!`````P`"Z#"__T4!````
M`P`"]#"__T(!`````P`#`#"__S\!`````P`###"__SP!`````P`#&#"__SD!
M`````P`#)#"__S8!`````P`#,#"__S,!`````P`#/#"__S`!`````P`#2#"_
M_RT!`````P`#5#"__RH!`````P`#8#"__R<!`````P`#;#"__R0!`````P`#
M>#"__R$!`````P`#A#"__QX!`````P`#D#"__QL!`````P`#G#"__Q@!````
M`P`#J#"__Q4!`````P`#M#"__Q(!`````P`#P#"__P\!`````P`#S#"__PP!
M`````P`#V#"__PD!`````P`#Y#"__P8!`````P`#\#"__P,!`````0``````
M``#_____``%<\```66T`1T-#.B`H1TY5*2`T+C0N,R`R,#$P,#$R,2`H4F5D
M($AA="`T+C0N,RTS*0``1T-#.B`H1TY5*2`T+C0N,R`R,#$P,#$R,2`H4F5D
M($AA="`T+C0N,RTS*0``1T-#.B`H1TY5*2`T+C0N,R`R,#$P,#$R,2`H4F5D
M($AA="`T+C0N,RTS*0``1T-#.B`H1TY5*2`T+C0N,R`R,#$P,#$R,2`H4F5D
M($AA="`T+C0N,RTS*0``1T-#.B`H1TY5*2`T+C0N,R`R,#$P,#$R,2`H4F5D
M($AA="`T+C0N,RTS*0``1T-#.B`H1TY5*2`T+C0N,R`R,#$P,#$R,2`H4F5D
M($AA="`T+C0N,RTS*0``1T-#.B`H1TY5*2`T+C0N,R`R,#$P,#$R,2`H4F5D
M($AA="`T+C0N,RTS*0``1T-#.B`H1TY5*2`T+C0N,R`R,#$P,#$R,2`H4F5D
M($AA="`T+C0N,RTS*0``1T-#.B`H1TY5*2`T+C0N,R`R,#$P,#$R,2`H4F5D
M($AA="`T+C0N,RTS*0``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A
M9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T
M<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA
M+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`
M+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N9'EN86UI8P`N9V]T`"YD
M871A`"YB<W,`+F-O;6UE;G0`````````````````````````````````````
M````````````````````````"P````$````"``$!-````30````3````````
M```````!`````````!,````'`````@`!`4@```%(````(```````````````
M!``````````A````!P````(``0%H```!:````"0```````````````0`````
M````-&____8````"``$!C````8P```/4````!0`````````$````!````#X`
M```+`````@`!!6````5@```',`````8````!````!````!````!&`````P``
M``(``0R0```,D```!E0```````````````$`````````3F____\````"``$2
MY```$N0```#F````!0`````````"`````@```%MO___^`````@`!$\P``!/,
M````H`````8````"````!`````````!J````!`````(``11L```4;````"0`
M```%``````````0````,````=`````0````"``$4D```%)````/,````!0``
M`!8````$````#````'X````!````!@`!&%P``!A<````4```````````````
M!`````````"$`````0````8``1C````8P```/@```````````````"``````
M````B@````$````&``%6P```5L`````4```````````````$`````````)``
M```!`````@`!5M@``%;8``!?D```````````````"`````````"8`````0``
M``(``;9H``"V:````.P```````````````0`````````I@````$````"``&W
M5```MU0```,$```````````````$`````````+`````!`````P`"P````,``
M````"```````````````!`````````"W`````0````,``L`(``#`"`````@`
M``````````````0`````````O@````$````#``+`$```P!`````$````````
M```````$`````````,,````&`````P`"P!0``,`4```!$`````8`````````
M!`````@```#,`````0````,``L$D``#!)````!0```````````````0````$
M````>0````$````'``+!.```P3@```0````````````````$`````````-$`
M```!`````P`"Q3@``,4X````$```````````````!`````````#7````"```
M``,``L5(``#%2```$$````````````````@`````````W`````$`````````
M````Q4@```&5```````````````!``````````$````#`````````````,;=
4````Y0```````````````0``````
